import{m as k,l as S}from"./icons.5353538a.js";import{d as h,K as b,b as s,c as a,x as l,F as p,L as R,z as i,G as m,N as f,q as _,v as I,D as d,e as N,I as w,t as x,O as C,Q as D}from"./registerWidgets.309e60e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d9a17fd8-3682-4160-8f73-12375a02a57d",e._sentryDebugIdIdentifier="sentry-dbid-d9a17fd8-3682-4160-8f73-12375a02a57d")}catch{}})();const $={class:"sidebar-content"},B={class:"section"},E=["onClick"],P=h({__name:"Sidebar",props:{currentRuntime:null,displaySidebar:{type:Boolean},forceResponsivity:null},emits:["selectRuntime","closeSidebar"],setup(e,{emit:r}){const o=e,u=b(()=>o.currentRuntime.runtimeType==="dash"),c=t=>{n(t.id)||r("selectRuntime",t)},v=b(()=>o.currentRuntime.sidebar.filter(t=>t.visible)),n=t=>t===o.currentRuntime.id;return(t,g)=>(s(),a("div",{class:m(["sidebar",e.forceResponsivity,{open:e.displaySidebar,dash:i(u)}])},[l("div",$,[l("div",B,[(s(!0),a(p,null,R(i(v),y=>(s(),a("div",{key:y.id,class:m(["item",{active:n(y.id)}]),onClick:Q=>c(y)},[l("div",{class:m(["item-title",{open:e.displaySidebar}])},f(y.name),3)],10,E))),128))])])],2))}});const U=_(P,[["__scopeId","data-v-09ca60c8"]]),T=e=>(C("data-v-a92d79dd"),e=e(),D(),e),V={class:"left-side"},z=["d"],F={key:1,class:"brand"},L=["src"],q={key:1,class:"brand-name"},G=T(()=>l("div",null,null,-1)),K={key:0,class:"signed-email"},O=h({__name:"PlayerNavbar",props:{runtime:null,brandName:null,userEmail:null,forceResponsivity:null},emits:["logout","navigate"],setup(e,{emit:r}){const o=e,u=I({displaySidebar:!1}),c=b(()=>{const n=o.runtime.sidebar;return!n||n.length==0?!1:n.some(t=>t.visible)}),v=n=>r("navigate",n);return(n,t)=>(s(),a(p,null,[i(c)||e.runtime.logoUrl||e.runtime.brandName||e.userEmail?(s(),a("div",{key:0,class:m(["navbar",(e.runtime.runtimeType=="dash"||i(c))&&"background"])},[l("div",V,[i(c)?(s(),a("svg",{key:0,class:m(["sidebar-menu-icon",e.forceResponsivity,{dash:e.runtime.runtimeType=="dash"}]),viewBox:"0 0 24 24",fill:"var(--color-main)",onClick:t[0]||(t[0]=g=>u.displaySidebar=!u.displaySidebar)},[l("path",{d:i(k)},null,8,z)],2)):d("",!0),e.runtime.logoUrl||e.runtime.brandName?(s(),a("div",F,[e.runtime.logoUrl?(s(),a("img",{key:0,src:e.runtime.logoUrl,class:"logo-image"},null,8,L)):d("",!0),e.runtime.brandName?(s(),a("p",q,f(e.runtime.brandName),1)):d("",!0)])):d("",!0)]),G,e.userEmail?(s(),a("div",K,[l("span",null,f(e.userEmail),1),N(w,{width:"20",height:"20",class:"logout",path:i(S),fill:"var(--color-main)",onClick:t[1]||(t[1]=g=>r("logout"))},null,8,["path"])])):d("",!0)],2)):d("",!0),i(c)?(s(),x(U,{key:1,"current-runtime":e.runtime,"display-sidebar":u.displaySidebar,"force-responsivity":e.forceResponsivity,onSelectRuntime:v},null,8,["current-runtime","display-sidebar","force-responsivity"])):d("",!0)],64))}});const H=_(O,[["__scopeId","data-v-a92d79dd"]]);export{H as P};
//# sourceMappingURL=PlayerNavbar.81125f1f.js.map
