import{v as s}from"./icons.5353538a.js";import{d as r,a as c,b as d,c as i,e as _,z as l,U as u,q as f}from"./registerWidgets.309e60e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8e28ba37-67f3-4175-9bd4-062eaec6a48d",e._sentryDebugIdIdentifier="sentry-dbid-8e28ba37-67f3-4175-9bd4-062eaec6a48d")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const v=f(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.03de6942.js.map
