import{S as m}from"./Sidebar.dbb27ab4.js";import{N as d}from"./Navbar.590e241e.js";import{E as p,F as l,G as u}from"./icons.5353538a.js";import{d as _,K as b,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.309e60e2.js";import{a as h}from"./asyncComputed.b00f3898.js";import"./gateway.51cb6e51.js";import{O}from"./organization.ff0a826c.js";import"./index.1c1ab019.js";import"./Tooltip.02f3eb3d.js";import"./logo.084e5d7c.js";import"./passwordlessManager.707ad0fd.js";import"./pubsub.5200d147.js";import"./activeRecord.fda98ee0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="38057f2a-92eb-4436-ac44-1c28ead54919",e._sentryDebugIdIdentifier="sentry-dbid-38057f2a-92eb-4436-ac44-1c28ead54919")}catch{}})();const x={class:"organization"},k=_({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=b(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:p,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(d,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(m,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const R=I(k,[["__scopeId","data-v-7eef90b7"]]);export{R as default};
//# sourceMappingURL=Organization.4312ba23.js.map
