import{d as u,K as f,b as y,t as g,z as s,J as _}from"./registerWidgets.309e60e2.js";import{a as w}from"./asyncComputed.b00f3898.js";import"./gateway.51cb6e51.js";import{M as i}from"./member.a0b2037e.js";import"./index.1c1ab019.js";import{C as I}from"./CrudView.7aecf6b4.js";import"./passwordlessManager.707ad0fd.js";import"./pubsub.5200d147.js";import"./activeRecord.fda98ee0.js";import"./DropdownMenu.5c576288.js";import"./Modal.93f98c35.js";import"./LoadingIndicator.bc80793d.js";import"./lottie.e2f196ac.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="dd24d267-6b5d-463a-b42f-48b3249710c5",e._sentryDebugIdIdentifier="sentry-dbid-dd24d267-6b5d-463a-b42f-48b3249710c5")}catch{}})();const K=u({__name:"Members",setup(e){const a=_().params.organizationId,m=[{key:"email",label:"Email"}],d=async t=>{await i.create(a,t.email),p()},{loading:l,result:c,refetch:p}=w(()=>i.list(a)),b=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(b),"create-button-text":"Add members",fields:m,onCreate:d},null,8,["loading","table"]))}});export{K as default};
//# sourceMappingURL=Members.3df57349.js.map
