import{M as a}from"./Modal.93f98c35.js";import{d as r,v as c,r as _,b as d,c as l,e as n,w as f,F as i,a as m,x as u,q as b}from"./registerWidgets.309e60e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2226a876-aecb-4ab2-9336-202610f03c0b",e._sentryDebugIdIdentifier="sentry-dbid-2226a876-aecb-4ab2-9336-202610f03c0b")}catch{}})();const p=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=_(null);return(g,v)=>{const s=m("router-view");return d(),l(i,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:f(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const I=b(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.863d1377.js.map
