import{P as n}from"./Passwordless.80f7e38a.js";import{N as r}from"./Navbar.590e241e.js";import{d as i,b as d,c,e as t,H as p,q as _}from"./registerWidgets.309e60e2.js";import{M as m}from"./member.a0b2037e.js";import"./CircularLoading.ab75fdfe.js";import"./lottie.e2f196ac.js";import"./icons.5353538a.js";import"./passwordlessManager.707ad0fd.js";import"./pubsub.5200d147.js";import"./logo.084e5d7c.js";import"./asyncComputed.b00f3898.js";import"./gateway.51cb6e51.js";import"./activeRecord.fda98ee0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="7eea2096-633d-4c8f-94b6-9ae3a52aae33",e._sentryDebugIdIdentifier="sentry-dbid-7eea2096-633d-4c8f-94b6-9ae3a52aae33")}catch{}})();const f={class:"login"},l=i({__name:"Login",setup(e){const o=p();async function s(a){await m.login(),o.push({name:"home"})}return(a,u)=>(d(),c("div",f,[t(r,{class:"nav"}),t(n,{class:"passwordless",onDone:s})]))}});const B=_(l,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.71dae63e.js.map
