import{q as t,b as c,c as s}from"./registerWidgets.309e60e2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="cec2762c-5cf9-4ec1-9312-80b57a071d15",e._sentryDebugIdIdentifier="sentry-dbid-cec2762c-5cf9-4ec1-9312-80b57a071d15")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return c(),s("div",r,"Organization settings")}const f=t(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.23a0608d.js.map
